=======
Hacking
=======

Fork me on: https://bitbucket.org/icemac/icemac.addressbook

File an issue on: https://bitbucket.org/icemac/icemac.addressbook/issues

Create the documentation using ``tox``.

See :ref:`source-installation`, too.
